---
layout: default
title: monty.math.md
nav_exclude: true
---

# monty.math module

Addition math functions.

## monty.math.nCr(n, r)

Calculates nCr.

* **Parameters**
  * **n** (*int*) – total number of items.
  * **r** (*int*) – items to choose
* **Returns**
  nCr.

## monty.math.nPr(n, r)

Calculates nPr.

* **Parameters**
  * **n** (*int*) – total number of items.
  * **r** (*int*) – items to permute
* **Returns**
  nPr.